"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(
    hub, ctx, bucket: str, id_: str, expected_bucket_owner: str = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes a metrics configuration for the Amazon CloudWatch request metrics (specified by the metrics configuration ID) from the bucket. Note that this doesn't include the daily storage metrics.  To use this operation, you must have permissions to perform the s3:PutMetricsConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources. For information about CloudWatch request metrics for Amazon S3, see Monitoring Metrics with Amazon CloudWatch.  The following operations are related to DeleteBucketMetricsConfiguration:    GetBucketMetricsConfiguration     PutBucketMetricsConfiguration     ListBucketMetricsConfigurations     Monitoring Metrics with Amazon CloudWatch

    Args:
        bucket(str): The name of the bucket containing the metrics configuration to delete.
        id_(str): The ID used to identify the metrics configuration.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.metric_configuration.delete(
                ctx, bucket=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.metric_configuration.delete bucket=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="delete_bucket_metrics_configuration",
        op_kwargs={
            "Bucket": bucket,
            "Id": id_,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )


async def get(
    hub, ctx, bucket: str, id_: str, expected_bucket_owner: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a metrics configuration (specified by the metrics configuration ID) from the bucket. Note that this doesn't include the daily storage metrics.  To use this operation, you must have permissions to perform the s3:GetMetricsConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources.  For information about CloudWatch request metrics for Amazon S3, see Monitoring Metrics with Amazon CloudWatch. The following operations are related to GetBucketMetricsConfiguration:    PutBucketMetricsConfiguration     DeleteBucketMetricsConfiguration     ListBucketMetricsConfigurations     Monitoring Metrics with Amazon CloudWatch

    Args:
        bucket(str): The name of the bucket containing the metrics configuration to retrieve.
        id_(str): The ID used to identify the metrics configuration.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.metric_configuration.get(ctx, bucket=value, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.metric_configuration.get bucket=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_metrics_configuration",
        op_kwargs={
            "Bucket": bucket,
            "Id": id_,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )


async def list_all(
    hub,
    ctx,
    bucket: str,
    continuation_token: str = None,
    expected_bucket_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the metrics configurations for the bucket. The metrics configurations are only for the request metrics of the bucket and do not provide information on daily storage metrics. You can have up to 1,000 configurations per bucket. This action supports list pagination and does not return more than 100 configurations at a time. Always check the IsTruncated element in the response. If there are no more configurations to list, IsTruncated is set to false. If there are more configurations to list, IsTruncated is set to true, and there is a value in NextContinuationToken. You use the NextContinuationToken value to continue the pagination of the list by passing the value in continuation-token in the request to GET the next page. To use this operation, you must have permissions to perform the s3:GetMetricsConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources. For more information about metrics configurations and CloudWatch request metrics, see Monitoring Metrics with Amazon CloudWatch. The following operations are related to ListBucketMetricsConfigurations:    PutBucketMetricsConfiguration     GetBucketMetricsConfiguration     DeleteBucketMetricsConfiguration

    Args:
        bucket(str): The name of the bucket containing the metrics configurations to retrieve.
        continuation_token(str, optional): The marker that is used to continue a metrics configuration listing that has been truncated. Use the NextContinuationToken from a previously truncated list response to continue the listing. The continuation token is an opaque value that Amazon S3 understands. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.metric_configuration.list_all(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.metric_configuration.list_all bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="list_bucket_metrics_configurations",
        op_kwargs={
            "Bucket": bucket,
            "ContinuationToken": continuation_token,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )


async def put(
    hub,
    ctx,
    bucket: str,
    id_: str,
    metrics_configuration: Dict,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Sets a metrics configuration (specified by the metrics configuration ID) for the bucket. You can have up to 1,000 metrics configurations per bucket. If you're updating an existing metrics configuration, note that this is a full replacement of the existing metrics configuration. If you don't include the elements you want to keep, they are erased. To use this operation, you must have permissions to perform the s3:PutMetricsConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources. For information about CloudWatch request metrics for Amazon S3, see Monitoring Metrics with Amazon CloudWatch. The following operations are related to PutBucketMetricsConfiguration:    DeleteBucketMetricsConfiguration     PutBucketMetricsConfiguration     ListBucketMetricsConfigurations     GetBucketLifecycle has the following special error:   Error code: TooManyConfigurations    Description: You are attempting to create a new configuration but have already reached the 1,000-configuration limit.   HTTP Status Code: HTTP 400 Bad Request

    Args:
        bucket(str): The name of the bucket for which the metrics configuration is set.
        id_(str): The ID used to identify the metrics configuration.
        metrics_configuration(Dict): Specifies the metrics configuration.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.metric_configuration.put(
                ctx, bucket=value, id_=value, metrics_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.metric_configuration.put bucket=value, id_=value, metrics_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_metrics_configuration",
        op_kwargs={
            "Bucket": bucket,
            "Id": id_,
            "MetricsConfiguration": metrics_configuration,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, input_device_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the details for the input device

    Args:
        input_device_id(str): The unique ID of this input device. For example, hd-123456789abcdef.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.device.init.describe(
                ctx, input_device_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.device.init.describe input_device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="describe_input_device",
        op_kwargs={"InputDeviceId": input_device_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    List input devices

    Args:
        max_results(int, optional): Placeholder documentation for MaxResults. Defaults to None.
        next_token(str, optional): Placeholder documentation for __string. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.device.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.device.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="list_input_devices",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def transfer(
    hub,
    ctx,
    input_device_id: str,
    target_customer_id: str = None,
    target_region: str = None,
    transfer_message: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Start an input device transfer to another AWS account. After you make the request, the other account must accept or reject the transfer.

    Args:
        input_device_id(str): The unique ID of this input device. For example, hd-123456789abcdef.
        target_customer_id(str, optional): The AWS account ID (12 digits) for the recipient of the device transfer. Defaults to None.
        target_region(str, optional): The target AWS region to transfer the device. Defaults to None.
        transfer_message(str, optional): An optional message for the recipient. Maximum 280 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.device.init.transfer(
                ctx, input_device_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.device.init.transfer input_device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="transfer_input_device",
        op_kwargs={
            "InputDeviceId": input_device_id,
            "TargetCustomerId": target_customer_id,
            "TargetRegion": target_region,
            "TransferMessage": transfer_message,
        },
    )


async def update(
    hub,
    ctx,
    input_device_id: str,
    hd_device_settings: Dict = None,
    name: str = None,
    uhd_device_settings: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the parameters for the input device.

    Args:
        hd_device_settings(Dict, optional): The settings that you want to apply to the HD input device. Defaults to None.
        input_device_id(str): The unique ID of the input device. For example, hd-123456789abcdef.
        name(str, optional): The name that you assigned to this input device (not the unique ID). Defaults to None.
        uhd_device_settings(Dict, optional): The settings that you want to apply to the UHD input device. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.device.init.update(ctx, input_device_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.device.init.update input_device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="update_input_device",
        op_kwargs={
            "HdDeviceSettings": hd_device_settings,
            "InputDeviceId": input_device_id,
            "Name": name,
            "UhdDeviceSettings": uhd_device_settings,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    aggregate_types: List,
    resolution: str,
    start_date: str,
    end_date: str,
    asset_id: str = None,
    property_id: str = None,
    property_alias: str = None,
    qualities: List = None,
    time_ordering: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets aggregated values for an asset property. For more information, see Querying aggregates in the IoT SiteWise User Guide. To identify an asset property, you must specify one of the following:   The assetId and propertyId of an asset property.   A propertyAlias, which is a data stream alias (for example, /company/windfarm/3/turbine/7/temperature). To define an asset property's alias, see UpdateAssetProperty.

    Args:
        asset_id(str, optional): The ID of the asset. Defaults to None.
        property_id(str, optional): The ID of the asset property. Defaults to None.
        property_alias(str, optional): The alias that identifies the property, such as an OPC-UA server data stream path (for example, /company/windfarm/3/turbine/7/temperature). For more information, see Mapping industrial data streams to asset properties in the IoT SiteWise User Guide. Defaults to None.
        aggregate_types(List): The data aggregating function.
        resolution(str): The time interval over which to aggregate data.
        qualities(List, optional): The quality by which to filter asset data. Defaults to None.
        start_date(str): The exclusive start of the range from which to query historical data, expressed in seconds in Unix epoch time.
        end_date(str): The inclusive end of the range from which to query historical data, expressed in seconds in Unix epoch time.
        time_ordering(str, optional): The chronological sorting order of the requested information. Default: ASCENDING . Defaults to None.
        next_token(str, optional): The token to be used for the next set of paginated results. Defaults to None.
        max_results(int, optional): The maximum number of results to return for each paginated request. Default: 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.asset.property_.aggregate.get_all(
                ctx, aggregate_types=value, resolution=value, start_date=value, end_date=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.asset.property_.aggregate.get_all aggregate_types=value, resolution=value, start_date=value, end_date=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="get_asset_property_aggregates",
        op_kwargs={
            "assetId": asset_id,
            "propertyId": property_id,
            "propertyAlias": property_alias,
            "aggregateTypes": aggregate_types,
            "resolution": resolution,
            "qualities": qualities,
            "startDate": start_date,
            "endDate": end_date,
            "timeOrdering": time_ordering,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    elastic_gpu_ids: List = None,
    dry_run: bool = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the Elastic Graphics accelerator associated with your instances. For more information about Elastic Graphics, see Amazon Elastic Graphics.

    Args:
        elastic_gpu_ids(List, optional): The Elastic Graphics accelerator IDs. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        filters(List, optional): The filters.    availability-zone - The Availability Zone in which the Elastic Graphics accelerator resides.    elastic-gpu-health - The status of the Elastic Graphics accelerator (OK | IMPAIRED).    elastic-gpu-state - The state of the Elastic Graphics accelerator (ATTACHED).    elastic-gpu-type - The type of Elastic Graphics accelerator; for example, eg1.medium.    instance-id - The ID of the instance to which the Elastic Graphics accelerator is associated.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. This value can be between 5 and 1000. Defaults to None.
        next_token(str, optional): The token to request the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.elastic_gpus.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.elastic_gpus.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_elastic_gpus",
        op_kwargs={
            "ElasticGpuIds": elastic_gpu_ids,
            "DryRun": dry_run,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub,
    ctx,
    filter_: Dict = None,
    next_token: str = None,
    max_results: int = None,
    locale: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about events across your organization in AWS Organizations. You can use thefilters parameter to specify the events that you want to return. Events are returned in a summary form and don't include the affected accounts, detailed description, any additional metadata that depends on the event type, or any affected resources. To retrieve that information, use the following operations:    DescribeAffectedAccountsForOrganization     DescribeEventDetailsForOrganization     DescribeAffectedEntitiesForOrganization    If you don't specify a filter, the DescribeEventsForOrganizations returns all events across your organization. Results are sorted by lastModifiedTime, starting with the most recent event.  For more information about the different types of AWS Health events, see Event. Before you can call this operation, you must first enable AWS Health to work with AWS Organizations. To do this, call the EnableHealthServiceAccessForOrganization operation from your organization's management account.  This API operation uses pagination. Specify the nextToken parameter in the next request to return more results.

    Args:
        filter_(Dict, optional): Values to narrow the results returned. Defaults to None.
        next_token(str, optional): If the results of a search are large, only a portion of the results are returned, and a nextToken pagination token is returned in the response. To retrieve the next batch of results, reissue the search request and include the returned token. When all results have been returned, the response does not contain a pagination token value. Defaults to None.
        max_results(int, optional): The maximum number of items to return in one batch, between 10 and 100, inclusive. Defaults to None.
        locale(str, optional): The locale (language) to return information in. English (en) is the default and the only supported value at this time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.health.event.for_organization.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.health.event.for_organization.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="health",
        operation="describe_events_for_organization",
        op_kwargs={
            "filter": filter_,
            "nextToken": next_token,
            "maxResults": max_results,
            "locale": locale,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    job_id: str,
    max_results: int = None,
    next_token: str = None,
    sort_by: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the celebrity recognition results for a Amazon Rekognition Video analysis started by StartCelebrityRecognition. Celebrity recognition in a video is an asynchronous operation. Analysis is started by a call to StartCelebrityRecognition which returns a job identifier (JobId). When the celebrity recognition operation finishes, Amazon Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic registered in the initial call to StartCelebrityRecognition. To get the results of the celebrity recognition analysis, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetCelebrityDetection and pass the job identifier (JobId) from the initial call to StartCelebrityDetection.  For more information, see Working With Stored Videos in the Amazon Rekognition Developer Guide.  GetCelebrityRecognition returns detected celebrities and the time(s) they are detected in an array (Celebrities) of CelebrityRecognition objects. Each CelebrityRecognition contains information about the celebrity in a CelebrityDetail object and the time, Timestamp, the celebrity was detected.    GetCelebrityRecognition only returns the default facial attributes (BoundingBox, Confidence, Landmarks, Pose, and Quality). The other facial attributes listed in the Face object of the following response syntax are not returned. For more information, see FaceDetail in the Amazon Rekognition Developer Guide.   By default, the Celebrities array is sorted by time (milliseconds from the start of the video). You can also sort the array by celebrity by specifying the value ID in the SortBy input parameter. The CelebrityDetail object includes the celebrity identifer and additional information urls. If you don't store the additional information urls, you can get them later by calling GetCelebrityInfo with the celebrity identifer. No information is returned for faces not recognized as celebrities. Use MaxResults parameter to limit the number of labels returned. If there are more results than specified in MaxResults, the value of NextToken in the operation response contains a pagination token for getting the next set of results. To get the next page of results, call GetCelebrityDetection and populate the NextToken request parameter with the token value returned from the previous call to GetCelebrityRecognition.

    Args:
        job_id(str): Job identifier for the required celebrity recognition analysis. You can get the job identifer from a call to StartCelebrityRecognition.
        max_results(int, optional): Maximum number of results to return per paginated call. The largest value you can specify is 1000. If you specify a value greater than 1000, a maximum of 1000 results is returned. The default value is 1000. Defaults to None.
        next_token(str, optional): If the previous response was incomplete (because there is more recognized celebrities to retrieve), Amazon Rekognition Video returns a pagination token in the response. You can use this pagination token to retrieve the next set of celebrities. . Defaults to None.
        sort_by(str, optional): Sort to use for celebrities returned in Celebrities field. Specify ID to sort by the celebrity identifier, specify TIMESTAMP to sort by the time the celebrity was recognized. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.celebrity.recognition.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.celebrity.recognition.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="get_celebrity_recognition",
        op_kwargs={
            "JobId": job_id,
            "MaxResults": max_results,
            "NextToken": next_token,
            "SortBy": sort_by,
        },
    )


async def start(
    hub,
    ctx,
    video: Dict,
    client_request_token: str = None,
    notification_channel: Dict = None,
    job_tag: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts asynchronous recognition of celebrities in a stored video. Amazon Rekognition Video can detect celebrities in a video must be stored in an Amazon S3 bucket. Use Video to specify the bucket name and the filename of the video. StartCelebrityRecognition returns a job identifier (JobId) which you use to get the results of the analysis. When celebrity recognition analysis is finished, Amazon Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic that you specify in NotificationChannel. To get the results of the celebrity recognition analysis, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetCelebrityRecognition and pass the job identifier (JobId) from the initial call to StartCelebrityRecognition.  For more information, see Recognizing Celebrities in the Amazon Rekognition Developer Guide.

    Args:
        video(Dict): The video in which you want to recognize celebrities. The video must be stored in an Amazon S3 bucket.
        client_request_token(str, optional): Idempotent token used to identify the start request. If you use the same token with multiple StartCelebrityRecognition requests, the same JobId is returned. Use ClientRequestToken to prevent the same job from being accidently started more than once. . Defaults to None.
        notification_channel(Dict, optional): The Amazon SNS topic ARN that you want Amazon Rekognition Video to publish the completion status of the celebrity recognition analysis to. Defaults to None.
        job_tag(str, optional): An identifier you specify that's returned in the completion notification that's published to your Amazon Simple Notification Service topic. For example, you can use JobTag to group related jobs and identify them in the completion notification. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.celebrity.recognition.start(ctx, video=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.celebrity.recognition.start video=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="start_celebrity_recognition",
        op_kwargs={
            "Video": video,
            "ClientRequestToken": client_request_token,
            "NotificationChannel": notification_channel,
            "JobTag": job_tag,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "object"


async def describe_all(
    hub,
    ctx,
    pipeline_id: str,
    object_ids: List,
    evaluate_expressions: bool = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the object definitions for a set of objects associated with the pipeline. Object definitions are composed of a set of fields that define the properties of the object.

    Args:
        pipeline_id(str): The ID of the pipeline that contains the object definitions.
        object_ids(List): The IDs of the pipeline objects that contain the definitions to be described. You can pass as many as 25 identifiers in a single call to DescribeObjects.
        evaluate_expressions(bool, optional): Indicates whether any expressions in the object should be evaluated when the object descriptions are returned. Defaults to None.
        marker(str, optional): The starting point for the results to be returned. For the first call, this value should be empty. As long as there are more results, continue to call DescribeObjects with the marker value from the previous call to retrieve the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datapipeline.object_.describe_all(
                ctx, pipeline_id=value, object_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datapipeline.object.describe_all pipeline_id=value, object_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datapipeline",
        operation="describe_objects",
        op_kwargs={
            "pipelineId": pipeline_id,
            "objectIds": object_ids,
            "evaluateExpressions": evaluate_expressions,
            "marker": marker,
        },
    )


async def query(
    hub,
    ctx,
    pipeline_id: str,
    sphere: str,
    query: Dict = None,
    marker: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Queries the specified pipeline for the names of objects that match the specified set of conditions.

    Args:
        pipeline_id(str): The ID of the pipeline.
        query(Dict, optional): The query that defines the objects to be returned. The Query object can contain a maximum of ten selectors. The conditions in the query are limited to top-level String fields in the object. These filters can be applied to components, instances, and attempts. Defaults to None.
        sphere(str): Indicates whether the query applies to components or instances. The possible values are: COMPONENT, INSTANCE, and ATTEMPT.
        marker(str, optional): The starting point for the results to be returned. For the first call, this value should be empty. As long as there are more results, continue to call QueryObjects with the marker value from the previous call to retrieve the next set of results. Defaults to None.
        limit(int, optional): The maximum number of object names that QueryObjects will return in a single call. The default value is 100. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datapipeline.object_.query(ctx, pipeline_id=value, sphere=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datapipeline.object.query pipeline_id=value, sphere=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datapipeline",
        operation="query_objects",
        op_kwargs={
            "pipelineId": pipeline_id,
            "query": query,
            "sphere": sphere,
            "marker": marker,
            "limit": limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    service_code: str = None,
    filters: List = None,
    format_version: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all products that match the filter criteria.

    Args:
        service_code(str, optional): The code for the service whose products you want to retrieve. . Defaults to None.
        filters(List, optional): The list of filters that limit the returned products. only products that match all filters are returned. Defaults to None.
        format_version(str, optional): The format version that you want the response to be in. Valid values are: aws_v1 . Defaults to None.
        next_token(str, optional): The pagination token that indicates the next set of results that you want to retrieve. Defaults to None.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pricing.product.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pricing.product.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pricing",
        operation="get_products",
        op_kwargs={
            "ServiceCode": service_code,
            "Filters": filters,
            "FormatVersion": format_version,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, consumer_arn: str, tracker_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates an association between a geofence collection and a tracker resource. This allows the tracker resource to communicate location data to the linked geofence collection.  You can associate up to five geofence collections to each tracker resource.  Currently not supported — Cross-account configurations, such as creating associations between a tracker resource in one account and a geofence collection in another account.

    Args:
        consumer_arn(str): The Amazon Resource Name (ARN) for the geofence collection to be associated to tracker resource. Used when you need to specify a resource across all AWS.   Format example: arn:aws:geo:region:account-id:geofence-collection/ExampleGeofenceCollectionConsumer   .
        tracker_name(str): The name of the tracker resource to be associated with a geofence collection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.tracker.consumer.associate(
                ctx, consumer_arn=value, tracker_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.tracker.consumer.associate consumer_arn=value, tracker_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="associate_tracker_consumer",
        op_kwargs={"ConsumerArn": consumer_arn, "TrackerName": tracker_name},
    )


async def disassociate(hub, ctx, consumer_arn: str, tracker_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes the association between a tracker resource and a geofence collection.  Once you unlink a tracker resource from a geofence collection, the tracker positions will no longer be automatically evaluated against geofences.

    Args:
        consumer_arn(str): The Amazon Resource Name (ARN) for the geofence collection to be disassociated from the tracker resource. Used when you need to specify a resource across all AWS.    Format example: arn:aws:geo:region:account-id:geofence-collection/ExampleGeofenceCollectionConsumer   .
        tracker_name(str): The name of the tracker resource to be dissociated from the consumer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.tracker.consumer.disassociate(
                ctx, consumer_arn=value, tracker_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.tracker.consumer.disassociate consumer_arn=value, tracker_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="disassociate_tracker_consumer",
        op_kwargs={"ConsumerArn": consumer_arn, "TrackerName": tracker_name},
    )


async def list_all(
    hub, ctx, tracker_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists geofence collections currently associated to the given tracker resource.

    Args:
        max_results(int, optional): An optional limit for the number of resources returned in a single call.  Default value: 100 . Defaults to None.
        next_token(str, optional): The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.  Default value: null . Defaults to None.
        tracker_name(str): The tracker resource whose associated geofence collections you want to list.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.tracker.consumer.list_all(ctx, tracker_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.tracker.consumer.list_all tracker_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="list_tracker_consumers",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "TrackerName": tracker_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    job_definition_name: str,
    data_quality_app_specification: Dict,
    data_quality_job_input: Dict,
    data_quality_job_output_config: Dict,
    job_resources: Dict,
    role_arn: str,
    data_quality_baseline_config: Dict = None,
    network_config: Dict = None,
    stopping_condition: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a definition for a job that monitors data quality and drift. For information about model monitor, see Amazon SageMaker Model Monitor.

    Args:
        job_definition_name(str): The name for the monitoring job definition.
        data_quality_baseline_config(Dict, optional): Configures the constraints and baselines for the monitoring job. Defaults to None.
        data_quality_app_specification(Dict): Specifies the container that runs the monitoring job.
        data_quality_job_input(Dict): A list of inputs for the monitoring job. Currently endpoints are supported as monitoring inputs.
        data_quality_job_output_config(Dict): The output configuration for monitoring jobs.
        job_resources(Dict): Identifies the resources to deploy for a monitoring job.
        network_config(Dict, optional): Specifies networking configuration for the monitoring job. Defaults to None.
        role_arn(str): The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
        stopping_condition(Dict, optional): A time limit for how long the monitoring job is allowed to run before stopping. Defaults to None.
        tags(List, optional): (Optional) An array of key-value pairs. For more information, see Using Cost Allocation Tags in the Amazon Web Services Billing and Cost Management User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.data_quality_job_definition.create(
                ctx,
                job_definition_name=value,
                data_quality_app_specification=value,
                data_quality_job_input=value,
                data_quality_job_output_config=value,
                job_resources=value,
                role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.data_quality_job_definition.create job_definition_name=value, data_quality_app_specification=value, data_quality_job_input=value, data_quality_job_output_config=value, job_resources=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_data_quality_job_definition",
        op_kwargs={
            "JobDefinitionName": job_definition_name,
            "DataQualityBaselineConfig": data_quality_baseline_config,
            "DataQualityAppSpecification": data_quality_app_specification,
            "DataQualityJobInput": data_quality_job_input,
            "DataQualityJobOutputConfig": data_quality_job_output_config,
            "JobResources": job_resources,
            "NetworkConfig": network_config,
            "RoleArn": role_arn,
            "StoppingCondition": stopping_condition,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, job_definition_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a data quality monitoring job definition.

    Args:
        job_definition_name(str): The name of the data quality monitoring job definition to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.data_quality_job_definition.delete(
                ctx, job_definition_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.data_quality_job_definition.delete job_definition_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_data_quality_job_definition",
        op_kwargs={"JobDefinitionName": job_definition_name},
    )


async def describe(hub, ctx, job_definition_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the details of a data quality monitoring job definition.

    Args:
        job_definition_name(str): The name of the data quality monitoring job definition to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.data_quality_job_definition.describe(
                ctx, job_definition_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.data_quality_job_definition.describe job_definition_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_data_quality_job_definition",
        op_kwargs={"JobDefinitionName": job_definition_name},
    )


async def list_all(
    hub,
    ctx,
    endpoint_name: str = None,
    sort_by: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
    name_contains: str = None,
    creation_time_before: str = None,
    creation_time_after: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the data quality job definitions in your account.

    Args:
        endpoint_name(str, optional): A filter that lists the data quality job definitions associated with the specified endpoint. Defaults to None.
        sort_by(str, optional): The field to sort results by. The default is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order for results. The default is Descending. Defaults to None.
        next_token(str, optional): If the result of the previous ListDataQualityJobDefinitions request was truncated, the response includes a NextToken. To retrieve the next set of transform jobs, use the token in the next request.>. Defaults to None.
        max_results(int, optional): The maximum number of data quality monitoring job definitions to return in the response. Defaults to None.
        name_contains(str, optional): A string in the data quality monitoring job definition name. This filter returns only data quality monitoring job definitions whose name contains the specified string. Defaults to None.
        creation_time_before(str, optional): A filter that returns only data quality monitoring job definitions created before the specified time. Defaults to None.
        creation_time_after(str, optional): A filter that returns only data quality monitoring job definitions created after the specified time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.data_quality_job_definition.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.data_quality_job_definition.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_data_quality_job_definitions",
        op_kwargs={
            "EndpointName": endpoint_name,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
            "NameContains": name_contains,
            "CreationTimeBefore": creation_time_before,
            "CreationTimeAfter": creation_time_after,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub, ctx, application_name: str, application_version_id: int
) -> Dict:
    r"""
    **Autogenerated function**

    Provides a detailed description of a specified version of the application. To see a list of all the versions of an application, invoke the ListApplicationVersions operation.  This operation is supported only for Amazon Kinesis Data Analytics for Apache Flink.

    Args:
        application_name(str): The name of the application for which you want to get the version description.
        application_version_id(int): The ID of the application version for which you want to get the description.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.version.describe(
                ctx, application_name=value, application_version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.version.describe application_name=value, application_version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="describe_application_version",
        op_kwargs={
            "ApplicationName": application_name,
            "ApplicationVersionId": application_version_id,
        },
    )


async def list_all(
    hub, ctx, application_name: str, limit: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the versions for the specified application, including versions that were rolled back. The response also includes a summary of the configuration associated with each version. To get the complete description of a specific application version, invoke the DescribeApplicationVersion operation.  This operation is supported only for Amazon Kinesis Data Analytics for Apache Flink.

    Args:
        application_name(str): The name of the application for which you want to list all versions.
        limit(int, optional): The maximum number of versions to list in this invocation of the operation. Defaults to None.
        next_token(str, optional): If a previous invocation of this operation returned a pagination token, pass it into this value to retrieve the next set of results. For more information about pagination, see Using the AWS Command Line Interface's Pagination Options. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.version.list_all(
                ctx, application_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.version.list_all application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="list_application_versions",
        op_kwargs={
            "ApplicationName": application_name,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    email_identity: str,
    tags: List = None,
    dkim_signing_attributes: Dict = None,
    configuration_set_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts the process of verifying an email identity. An identity is an email address or domain that you use when you send email. Before you can use an identity to send email, you first have to verify it. By verifying an identity, you demonstrate that you're the owner of the identity, and that you've given Amazon SES API v2 permission to send email from the identity. When you verify an email address, Amazon SES sends an email to the address. Your email address is verified as soon as you follow the link in the verification email.  When you verify a domain without specifying the DkimSigningAttributes object, this operation provides a set of DKIM tokens. You can convert these tokens into CNAME records, which you then add to the DNS configuration for your domain. Your domain is verified when Amazon SES detects these records in the DNS configuration for your domain. This verification method is known as Easy DKIM. Alternatively, you can perform the verification process by providing your own public-private key pair. This verification method is known as Bring Your Own DKIM (BYODKIM). To use BYODKIM, your call to the CreateEmailIdentity operation has to include the DkimSigningAttributes object. When you specify this object, you provide a selector (a component of the DNS record name that identifies the public key that you want to use for DKIM authentication) and a private key. When you verify a domain, this operation provides a set of DKIM tokens, which you can convert into CNAME tokens. You add these CNAME tokens to the DNS configuration for your domain. Your domain is verified when Amazon SES detects these records in the DNS configuration for your domain. For some DNS providers, it can take 72 hours or more to complete the domain verification process. Additionally, you can associate an existing configuration set with the email identity that you're verifying.

    Args:
        email_identity(str): The email address or domain that you want to verify.
        tags(List, optional): An array of objects that define the tags (keys and values) that you want to associate with the email identity. Defaults to None.
        dkim_signing_attributes(Dict, optional): If your request includes this object, Amazon SES configures the identity to use Bring Your Own DKIM (BYODKIM) for DKIM authentication purposes, as opposed to the default method, Easy DKIM. You can only specify this object if the email identity is a domain, as opposed to an address. Defaults to None.
        configuration_set_name(str, optional): The configuration set to use by default when sending from this identity. Note that any configuration set defined in the email sending request takes precedence. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.identity.init.create(ctx, email_identity=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.identity.init.create email_identity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="create_email_identity",
        op_kwargs={
            "EmailIdentity": email_identity,
            "Tags": tags,
            "DkimSigningAttributes": dkim_signing_attributes,
            "ConfigurationSetName": configuration_set_name,
        },
    )


async def delete(hub, ctx, email_identity: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an email identity. An identity can be either an email address or a domain name.

    Args:
        email_identity(str): The identity (that is, the email address or domain) that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.identity.init.delete(ctx, email_identity=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.identity.init.delete email_identity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="delete_email_identity",
        op_kwargs={"EmailIdentity": email_identity},
    )


async def get(hub, ctx, email_identity: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides information about a specific identity, including the identity's verification status, sending authorization policies, its DKIM authentication status, and its custom Mail-From settings.

    Args:
        email_identity(str): The email identity that you want to retrieve details for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.identity.init.get(ctx, email_identity=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.identity.init.get email_identity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="get_email_identity",
        op_kwargs={"EmailIdentity": email_identity},
    )


async def list_all(hub, ctx, next_token: str = None, page_size: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all of the email identities that are associated with your AWS account. An identity can be either an email address or a domain. This operation returns identities that are verified as well as those that aren't. This operation returns identities that are associated with Amazon SES and Amazon Pinpoint.

    Args:
        next_token(str, optional): A token returned from a previous call to ListEmailIdentities to indicate the position in the list of identities. Defaults to None.
        page_size(int, optional): The number of results to show in a single call to ListEmailIdentities. If the number of results is larger than the number you specified in this parameter, then the response includes a NextToken element, which you can use to obtain additional results. The value you specify has to be at least 0, and can be no more than 1000. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.identity.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.identity.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="list_email_identities",
        op_kwargs={"NextToken": next_token, "PageSize": page_size},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, name: str, container_provider: Dict, client_token: str, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a virtual cluster. Virtual cluster is a managed entity on Amazon EMR on EKS. You can create, describe, list and delete virtual clusters. They do not consume any additional resource in your system. A single virtual cluster maps to a single Kubernetes namespace. Given this relationship, you can model virtual clusters the same way you model Kubernetes namespaces to meet your requirements.

    Args:
        name(str): The specified name of the virtual cluster.
        container_provider(Dict): The container provider of the virtual cluster.
        client_token(str): The client token of the virtual cluster.
        tags(Dict, optional): The tags assigned to the virtual cluster. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr_container.virtual_cluster.create(
                ctx, name=value, container_provider=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr_container.virtual_cluster.create name=value, container_provider=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr-containers",
        operation="create_virtual_cluster",
        op_kwargs={
            "name": name,
            "containerProvider": container_provider,
            "clientToken": client_token,
            "tags": tags,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a virtual cluster. Virtual cluster is a managed entity on Amazon EMR on EKS. You can create, describe, list and delete virtual clusters. They do not consume any additional resource in your system. A single virtual cluster maps to a single Kubernetes namespace. Given this relationship, you can model virtual clusters the same way you model Kubernetes namespaces to meet your requirements.

    Args:
        id_(str): The ID of the virtual cluster that will be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr_container.virtual_cluster.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr_container.virtual_cluster.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr-containers",
        operation="delete_virtual_cluster",
        op_kwargs={"id": id_},
    )


async def describe(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Displays detailed information about a specified virtual cluster. Virtual cluster is a managed entity on Amazon EMR on EKS. You can create, describe, list and delete virtual clusters. They do not consume any additional resource in your system. A single virtual cluster maps to a single Kubernetes namespace. Given this relationship, you can model virtual clusters the same way you model Kubernetes namespaces to meet your requirements.

    Args:
        id_(str): The ID of the virtual cluster that will be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr_container.virtual_cluster.describe(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr_container.virtual_cluster.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr-containers",
        operation="describe_virtual_cluster",
        op_kwargs={"id": id_},
    )


async def list_all(
    hub,
    ctx,
    container_provider_id: str = None,
    container_provider_type: str = None,
    created_after: str = None,
    created_before: str = None,
    states: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists information about the specified virtual cluster. Virtual cluster is a managed entity on Amazon EMR on EKS. You can create, describe, list and delete virtual clusters. They do not consume any additional resource in your system. A single virtual cluster maps to a single Kubernetes namespace. Given this relationship, you can model virtual clusters the same way you model Kubernetes namespaces to meet your requirements.

    Args:
        container_provider_id(str, optional): The container provider ID of the virtual cluster. Defaults to None.
        container_provider_type(str, optional): The container provider type of the virtual cluster. EKS is the only supported type as of now. Defaults to None.
        created_after(str, optional): The date and time after which the virtual clusters are created. Defaults to None.
        created_before(str, optional): The date and time before which the virtual clusters are created. Defaults to None.
        states(List, optional): The states of the requested virtual clusters. Defaults to None.
        max_results(int, optional): The maximum number of virtual clusters that can be listed. Defaults to None.
        next_token(str, optional): The token for the next set of virtual clusters to return. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr_container.virtual_cluster.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr_container.virtual_cluster.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr-containers",
        operation="list_virtual_clusters",
        op_kwargs={
            "containerProviderId": container_provider_id,
            "containerProviderType": container_provider_type,
            "createdAfter": created_after,
            "createdBefore": created_before,
            "states": states,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, registry_id: Dict = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of schemas with minimal details. Schemas in Deleting status will not be included in the results. Empty results will be returned if there are no schemas available. When the RegistryId is not provided, all the schemas across registries will be part of the API response.

    Args:
        registry_id(Dict, optional): A wrapper structure that may contain the registry name and Amazon Resource Name (ARN). Defaults to None.
        max_results(int, optional): Maximum number of results required per page. If the value is not supplied, this will be defaulted to 25 per page. Defaults to None.
        next_token(str, optional): A continuation token, if this is a continuation call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.schemas.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.schemas.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="list_schemas",
        op_kwargs={
            "RegistryId": registry_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def stop(hub, ctx, resource_arn: str) -> None:
    r"""
    **Autogenerated function**

    Stops a resource. The resource undergoes the following states: CREATE_STOPPING and CREATE_STOPPED. You cannot resume a resource once it has been stopped. This operation can be applied to the following resources (and their corresponding child resources):   Dataset Import Job   Predictor Job   Forecast Job   Forecast Export Job   Predictor Backtest Export Job

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) that identifies the resource to stop. The supported ARNs are DatasetImportJobArn, PredictorArn, PredictorBacktestExportJobArn, ForecastArn, and ForecastExportJobArn. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.resource.init.stop(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.resource.init.stop resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="stop_resource",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Associates the specified tags to a resource with the specified resourceArn. If existing tags on a resource are not specified in the request parameters, they are not changed. When a resource is deleted, the tags associated with that resource are also deleted.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) that identifies the resource for which to list the tags. Currently, the supported resources are Forecast dataset groups, datasets, dataset import jobs, predictors, forecasts, and forecast export jobs.
        tags(List): The tags to add to the resource. A tag is an array of key-value pairs. The following basic restrictions apply to tags:   Maximum number of tags per resource - 50.   For each resource, each tag key must be unique, and each tag key can have only one value.   Maximum key length - 128 Unicode characters in UTF-8.   Maximum value length - 256 Unicode characters in UTF-8.   If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.   Tag keys and values are case sensitive.   Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Forecast considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.resource.init.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.resource.init.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified tags from a resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) that identifies the resource for which to list the tags. Currently, the supported resources are Forecast dataset groups, datasets, dataset import jobs, predictors, forecasts, and forecast exports.
        tag_keys(List): The keys of the tags to be removed.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.resource.init.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.resource.init.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub,
    ctx,
    job_id: str,
    thing_name: str,
    include_job_document: bool = None,
    execution_number: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets details of a job execution.

    Args:
        job_id(str): The unique identifier assigned to this job when it was created.
        thing_name(str): The thing name associated with the device the job execution is running on.
        include_job_document(bool, optional): Optional. When set to true, the response contains the job document. The default is false. Defaults to None.
        execution_number(int, optional): Optional. A number that identifies a particular job execution on a particular device. If not specified, the latest job execution is returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot_jobs_data.job_execution.describe(
                ctx, job_id=value, thing_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot_jobs_data.job_execution.describe job_id=value, thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot-jobs-data",
        operation="describe_job_execution",
        op_kwargs={
            "jobId": job_id,
            "thingName": thing_name,
            "includeJobDocument": include_job_document,
            "executionNumber": execution_number,
        },
    )


async def update(
    hub,
    ctx,
    job_id: str,
    thing_name: str,
    status: str,
    status_details: Dict = None,
    step_timeout_in_minutes: int = None,
    expected_version: int = None,
    include_job_execution_state: bool = None,
    include_job_document: bool = None,
    execution_number: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the status of a job execution.

    Args:
        job_id(str): The unique identifier assigned to this job when it was created.
        thing_name(str): The name of the thing associated with the device.
        status(str): The new status for the job execution (IN_PROGRESS, FAILED, SUCCESS, or REJECTED). This must be specified on every update.
        status_details(Dict, optional):  Optional. A collection of name/value pairs that describe the status of the job execution. If not specified, the statusDetails are unchanged. Defaults to None.
        step_timeout_in_minutes(int, optional): Specifies the amount of time this device has to finish execution of this job. If the job execution status is not set to a terminal state before this timer expires, or before the timer is reset (by again calling UpdateJobExecution, setting the status to IN_PROGRESS and specifying a new timeout value in this field) the job execution status will be automatically set to TIMED_OUT. Note that setting or resetting this timeout has no effect on that job execution timeout which may have been specified when the job was created (CreateJob using field timeoutConfig). Defaults to None.
        expected_version(int, optional): Optional. The expected current version of the job execution. Each time you update the job execution, its version is incremented. If the version of the job execution stored in Jobs does not match, the update is rejected with a VersionMismatch error, and an ErrorResponse that contains the current job execution status data is returned. (This makes it unnecessary to perform a separate DescribeJobExecution request in order to obtain the job execution status data.). Defaults to None.
        include_job_execution_state(bool, optional): Optional. When included and set to true, the response contains the JobExecutionState data. The default is false. Defaults to None.
        include_job_document(bool, optional): Optional. When set to true, the response contains the job document. The default is false. Defaults to None.
        execution_number(int, optional): Optional. A number that identifies a particular job execution on a particular device. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot_jobs_data.job_execution.update(
                ctx, job_id=value, thing_name=value, status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot_jobs_data.job_execution.update job_id=value, thing_name=value, status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot-jobs-data",
        operation="update_job_execution",
        op_kwargs={
            "jobId": job_id,
            "thingName": thing_name,
            "status": status,
            "statusDetails": status_details,
            "stepTimeoutInMinutes": step_timeout_in_minutes,
            "expectedVersion": expected_version,
            "includeJobExecutionState": include_job_execution_state,
            "includeJobDocument": include_job_document,
            "executionNumber": execution_number,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    file_system_id: str,
    subnet_id: str,
    ip_address: str = None,
    security_groups: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a mount target for a file system. You can then mount the file system on EC2 instances by using the mount target. You can create one mount target in each Availability Zone in your VPC. All EC2 instances in a VPC within a given Availability Zone share a single mount target for a given file system. If you have multiple subnets in an Availability Zone, you create a mount target in one of the subnets. EC2 instances do not need to be in the same subnet as the mount target in order to access their file system. You can create only one mount target for an EFS file system using One Zone storage classes. You must create that mount target in the same Availability Zone in which the file system is located. Use the AvailabilityZoneName and AvailabiltyZoneId properties in the DescribeFileSystems response object to get this information. Use the subnetId associated with the file system's Availability Zone when creating the mount target. For more information, see Amazon EFS: How it Works.  To create a mount target for a file system, the file system's lifecycle state must be available. For more information, see DescribeFileSystems. In the request, provide the following:   The file system ID for which you are creating the mount target.   A subnet ID, which determines the following:   The VPC in which Amazon EFS creates the mount target   The Availability Zone in which Amazon EFS creates the mount target   The IP address range from which Amazon EFS selects the IP address of the mount target (if you don't specify an IP address in the request)     After creating the mount target, Amazon EFS returns a response that includes, a MountTargetId and an IpAddress. You use this IP address when mounting the file system in an EC2 instance. You can also use the mount target's DNS name when mounting the file system. The EC2 instance on which you mount the file system by using the mount target can resolve the mount target's DNS name to its IP address. For more information, see How it Works: Implementation Overview.  Note that you can create mount targets for a file system in only one VPC, and there can be only one mount target per Availability Zone. That is, if the file system already has one or more mount targets created for it, the subnet specified in the request to add another mount target must meet the following requirements:   Must belong to the same VPC as the subnets of the existing mount targets   Must not be in the same Availability Zone as any of the subnets of the existing mount targets   If the request satisfies the requirements, Amazon EFS does the following:   Creates a new mount target in the specified subnet.   Also creates a new network interface in the subnet as follows:   If the request provides an IpAddress, Amazon EFS assigns that IP address to the network interface. Otherwise, Amazon EFS assigns a free address in the subnet (in the same way that the Amazon EC2 CreateNetworkInterface call does when a request does not specify a primary private IP address).   If the request provides SecurityGroups, this network interface is associated with those security groups. Otherwise, it belongs to the default security group for the subnet's VPC.   Assigns the description Mount target fsmt-id for file system fs-id  where  fsmt-id  is the mount target ID, and  fs-id  is the FileSystemId.   Sets the requesterManaged property of the network interface to true, and the requesterId value to EFS.   Each Amazon EFS mount target has one corresponding requester-managed EC2 network interface. After the network interface is created, Amazon EFS sets the NetworkInterfaceId field in the mount target's description to the network interface ID, and the IpAddress field to its address. If network interface creation fails, the entire CreateMountTarget operation fails.    The CreateMountTarget call returns only after creating the network interface, but while the mount target state is still creating, you can check the mount target creation status by calling the DescribeMountTargets operation, which among other things returns the mount target state.  We recommend that you create a mount target in each of the Availability Zones. There are cost considerations for using a file system in an Availability Zone through a mount target created in another Availability Zone. For more information, see Amazon EFS. In addition, by always using a mount target local to the instance's Availability Zone, you eliminate a partial failure scenario. If the Availability Zone in which your mount target is created goes down, then you can't access your file system through that mount target.  This operation requires permissions for the following action on the file system:    elasticfilesystem:CreateMountTarget    This operation also requires permissions for the following Amazon EC2 actions:    ec2:DescribeSubnets     ec2:DescribeNetworkInterfaces     ec2:CreateNetworkInterface

    Args:
        file_system_id(str): The ID of the file system for which to create the mount target.
        subnet_id(str): The ID of the subnet to add the mount target in. For file systems that use One Zone storage classes, use the subnet that is associated with the file system's Availability Zone.
        ip_address(str, optional): Valid IPv4 address within the address range of the specified subnet. Defaults to None.
        security_groups(List, optional): Up to five VPC security group IDs, of the form sg-xxxxxxxx. These must be for the same VPC as subnet specified. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.mount_target.init.create(
                ctx, file_system_id=value, subnet_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.mount_target.init.create file_system_id=value, subnet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="create_mount_target",
        op_kwargs={
            "FileSystemId": file_system_id,
            "SubnetId": subnet_id,
            "IpAddress": ip_address,
            "SecurityGroups": security_groups,
        },
    )


async def delete(hub, ctx, mount_target_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified mount target. This operation forcibly breaks any mounts of the file system by using the mount target that is being deleted, which might disrupt instances or applications using those mounts. To avoid applications getting cut off abruptly, you might consider unmounting any mounts of the mount target, if feasible. The operation also deletes the associated network interface. Uncommitted writes might be lost, but breaking a mount target using this operation does not corrupt the file system itself. The file system you created remains. You can mount an EC2 instance in your VPC by using another mount target. This operation requires permissions for the following action on the file system:    elasticfilesystem:DeleteMountTarget     The DeleteMountTarget call returns while the mount target state is still deleting. You can check the mount target deletion by calling the DescribeMountTargets operation, which returns a list of mount target descriptions for the given file system.   The operation also requires permissions for the following Amazon EC2 action on the mount target's network interface:    ec2:DeleteNetworkInterface

    Args:
        mount_target_id(str): The ID of the mount target to delete (String).
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.mount_target.init.delete(ctx, mount_target_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.mount_target.init.delete mount_target_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="delete_mount_target",
        op_kwargs={"MountTargetId": mount_target_id},
    )


async def describe_all(
    hub,
    ctx,
    max_items: int = None,
    marker: str = None,
    file_system_id: str = None,
    mount_target_id: str = None,
    access_point_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the descriptions of all the current mount targets, or a specific mount target, for a file system. When requesting all of the current mount targets, the order of mount targets returned in the response is unspecified. This operation requires permissions for the elasticfilesystem:DescribeMountTargets action, on either the file system ID that you specify in FileSystemId, or on the file system of the mount target that you specify in MountTargetId.

    Args:
        max_items(int, optional): (Optional) Maximum number of mount targets to return in the response. Currently, this number is automatically set to 10, and other values are ignored. The response is paginated at 100 per page if you have more than 100 mount targets. Defaults to None.
        marker(str, optional): (Optional) Opaque pagination token returned from a previous DescribeMountTargets operation (String). If present, it specifies to continue the list from where the previous returning call left off. Defaults to None.
        file_system_id(str, optional): (Optional) ID of the file system whose mount targets you want to list (String). It must be included in your request if an AccessPointId or MountTargetId is not included. Accepts either a file system ID or ARN as input. Defaults to None.
        mount_target_id(str, optional): (Optional) ID of the mount target that you want to have described (String). It must be included in your request if FileSystemId is not included. Accepts either a mount target ID or ARN as input. Defaults to None.
        access_point_id(str, optional): (Optional) The ID of the access point whose mount targets that you want to list. It must be included in your request if a FileSystemId or MountTargetId is not included in your request. Accepts either an access point ID or ARN as input. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.mount_target.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.mount_target.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="describe_mount_targets",
        op_kwargs={
            "MaxItems": max_items,
            "Marker": marker,
            "FileSystemId": file_system_id,
            "MountTargetId": mount_target_id,
            "AccessPointId": access_point_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def attach(
    hub, ctx, auto_scaling_group_name: str, target_group_ar_ns: List
) -> Dict:
    r"""
    **Autogenerated function**

    Attaches one or more target groups to the specified Auto Scaling group. This operation is used with the following load balancer types:     Application Load Balancer - Operates at the application layer (layer 7) and supports HTTP and HTTPS.     Network Load Balancer - Operates at the transport layer (layer 4) and supports TCP, TLS, and UDP.     Gateway Load Balancer - Operates at the network layer (layer 3).   To describe the target groups for an Auto Scaling group, call the DescribeLoadBalancerTargetGroups API. To detach the target group from the Auto Scaling group, call the DetachLoadBalancerTargetGroups API. For more information, see Elastic Load Balancing and Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        target_group_ar_ns(List): The Amazon Resource Names (ARN) of the target groups. You can specify up to 10 target groups. To get the ARN of a target group, use the Elastic Load Balancing DescribeTargetGroups API operation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.load_balancer.target_group.attach(
                ctx, auto_scaling_group_name=value, target_group_ar_ns=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.load_balancer.target_group.attach auto_scaling_group_name=value, target_group_ar_ns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="attach_load_balancer_target_groups",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "TargetGroupARNs": target_group_ar_ns,
        },
    )


async def describe_all(
    hub,
    ctx,
    auto_scaling_group_name: str,
    next_token: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the load balancer target groups for the specified Auto Scaling group. To determine the availability of registered instances, use the State element in the response. When you attach a target group to an Auto Scaling group, the initial State value is Adding. The state transitions to Added after all Auto Scaling instances are registered with the target group. If Elastic Load Balancing health checks are enabled for the Auto Scaling group, the state transitions to InService after at least one Auto Scaling instance passes the health check. When the target group is in the InService state, Amazon EC2 Auto Scaling can terminate and replace any instances that are reported as unhealthy. If no registered instances pass the health checks, the target group doesn't enter the InService state.  Target groups also have an InService state if you attach them in the CreateAutoScalingGroup API call. If your target group state is InService, but it is not working properly, check the scaling activities by calling DescribeScalingActivities and take any corrective actions necessary. For help with failed health checks, see Troubleshooting Amazon EC2 Auto Scaling: Health checks in the Amazon EC2 Auto Scaling User Guide. For more information, see Elastic Load Balancing and Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        max_records(int, optional): The maximum number of items to return with this call. The default value is 100 and the maximum value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.load_balancer.target_group.describe_all(
                ctx, auto_scaling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.load_balancer.target_group.describe_all auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="describe_load_balancer_target_groups",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "NextToken": next_token,
            "MaxRecords": max_records,
        },
    )


async def detach(
    hub, ctx, auto_scaling_group_name: str, target_group_ar_ns: List
) -> Dict:
    r"""
    **Autogenerated function**

    Detaches one or more target groups from the specified Auto Scaling group.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        target_group_ar_ns(List): The Amazon Resource Names (ARN) of the target groups. You can specify up to 10 target groups.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.load_balancer.target_group.detach(
                ctx, auto_scaling_group_name=value, target_group_ar_ns=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.load_balancer.target_group.detach auto_scaling_group_name=value, target_group_ar_ns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="detach_load_balancer_target_groups",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "TargetGroupARNs": target_group_ar_ns,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def start(hub, ctx, stream_name: str, encryption_type: str, key_id: str) -> None:
    r"""
    **Autogenerated function**

    Enables or updates server-side encryption using an AWS KMS key for a specified stream.  Starting encryption is an asynchronous operation. Upon receiving the request, Kinesis Data Streams returns immediately and sets the status of the stream to UPDATING. After the update is complete, Kinesis Data Streams sets the status of the stream back to ACTIVE. Updating or applying encryption normally takes a few seconds to complete, but it can take minutes. You can continue to read and write data to your stream while its status is UPDATING. Once the status of the stream is ACTIVE, encryption begins for records written to the stream.  API Limits: You can successfully apply a new AWS KMS key for server-side encryption 25 times in a rolling 24-hour period. Note: It can take up to 5 seconds after the stream is in an ACTIVE status before all records written to the stream are encrypted. After you enable encryption, you can verify that encryption is applied by inspecting the API response from PutRecord or PutRecords.

    Args:
        stream_name(str): The name of the stream for which to start encrypting records.
        encryption_type(str): The encryption type to use. The only valid value is KMS.
        key_id(str): The GUID for the customer-managed AWS KMS key to use for encryption. This value can be a globally unique identifier, a fully specified Amazon Resource Name (ARN) to either an alias or a key, or an alias name prefixed by "alias/".You can also use a master key owned by Kinesis Data Streams by specifying the alias aws/kinesis.   Key ARN example: arn:aws:kms:us-east-1:123456789012:key/12345678-1234-1234-1234-123456789012    Alias ARN example: arn:aws:kms:us-east-1:123456789012:alias/MyAliasName    Globally unique key ID example: 12345678-1234-1234-1234-123456789012    Alias name example: alias/MyAliasName    Master key owned by Kinesis Data Streams: alias/aws/kinesis   .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.stream.encryption.start(
                ctx, stream_name=value, encryption_type=value, key_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.stream.encryption.start stream_name=value, encryption_type=value, key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="start_stream_encryption",
        op_kwargs={
            "StreamName": stream_name,
            "EncryptionType": encryption_type,
            "KeyId": key_id,
        },
    )


async def stop(hub, ctx, stream_name: str, encryption_type: str, key_id: str) -> None:
    r"""
    **Autogenerated function**

    Disables server-side encryption for a specified stream.  Stopping encryption is an asynchronous operation. Upon receiving the request, Kinesis Data Streams returns immediately and sets the status of the stream to UPDATING. After the update is complete, Kinesis Data Streams sets the status of the stream back to ACTIVE. Stopping encryption normally takes a few seconds to complete, but it can take minutes. You can continue to read and write data to your stream while its status is UPDATING. Once the status of the stream is ACTIVE, records written to the stream are no longer encrypted by Kinesis Data Streams.  API Limits: You can successfully disable server-side encryption 25 times in a rolling 24-hour period.  Note: It can take up to 5 seconds after the stream is in an ACTIVE status before all records written to the stream are no longer subject to encryption. After you disabled encryption, you can verify that encryption is not applied by inspecting the API response from PutRecord or PutRecords.

    Args:
        stream_name(str): The name of the stream on which to stop encrypting records.
        encryption_type(str): The encryption type. The only valid value is KMS.
        key_id(str): The GUID for the customer-managed AWS KMS key to use for encryption. This value can be a globally unique identifier, a fully specified Amazon Resource Name (ARN) to either an alias or a key, or an alias name prefixed by "alias/".You can also use a master key owned by Kinesis Data Streams by specifying the alias aws/kinesis.   Key ARN example: arn:aws:kms:us-east-1:123456789012:key/12345678-1234-1234-1234-123456789012    Alias ARN example: arn:aws:kms:us-east-1:123456789012:alias/MyAliasName    Globally unique key ID example: 12345678-1234-1234-1234-123456789012    Alias name example: alias/MyAliasName    Master key owned by Kinesis Data Streams: alias/aws/kinesis   .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.stream.encryption.stop(
                ctx, stream_name=value, encryption_type=value, key_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.stream.encryption.stop stream_name=value, encryption_type=value, key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="stop_stream_encryption",
        op_kwargs={
            "StreamName": stream_name,
            "EncryptionType": encryption_type,
            "KeyId": key_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, product_type: str, e164_phone_numbers: List) -> Dict:
    r"""
    **Autogenerated function**

    Creates an order for phone numbers to be provisioned. For toll-free numbers, you cannot use the Amazon Chime Business Calling product type. For numbers outside the U.S., you must use the Amazon Chime SIP Media Application Dial-In product type.

    Args:
        product_type(str): The phone number product type.
        e164_phone_numbers(List): List of phone numbers, in E.164 format.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.phone_number.order.create(
                ctx, product_type=value, e164_phone_numbers=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.phone_number.order.create product_type=value, e164_phone_numbers=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_phone_number_order",
        op_kwargs={"ProductType": product_type, "E164PhoneNumbers": e164_phone_numbers},
    )


async def get(hub, ctx, phone_number_order_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves details for the specified phone number order, such as the order creation timestamp, phone numbers in E.164 format, product type, and order status.

    Args:
        phone_number_order_id(str): The ID for the phone number order.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.phone_number.order.get(ctx, phone_number_order_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.phone_number.order.get phone_number_order_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_phone_number_order",
        op_kwargs={"PhoneNumberOrderId": phone_number_order_id},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the phone number orders for the administrator's Amazon Chime account.

    Args:
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.phone_number.order.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.phone_number.order.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_phone_number_orders",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, aws_account_id: str, data_source_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the resource permissions for a data source.

    Args:
        aws_account_id(str): The Amazon Web Services account; ID.
        data_source_id(str): The ID of the data source. This ID is unique per Region; for each Amazon Web Services account;.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.data.source.permission.describe_all(
                ctx, aws_account_id=value, data_source_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.data.source.permission.describe_all aws_account_id=value, data_source_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_data_source_permissions",
        op_kwargs={"AwsAccountId": aws_account_id, "DataSourceId": data_source_id},
    )


async def update_multiple(
    hub,
    ctx,
    aws_account_id: str,
    data_source_id: str,
    grant_permissions: List = None,
    revoke_permissions: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the permissions to a data source.

    Args:
        aws_account_id(str): The Amazon Web Services account; ID.
        data_source_id(str): The ID of the data source. This ID is unique per Region; for each Amazon Web Services account;. .
        grant_permissions(List, optional): A list of resource permissions that you want to grant on the data source. Defaults to None.
        revoke_permissions(List, optional): A list of resource permissions that you want to revoke on the data source. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.data.source.permission.update_multiple(
                ctx, aws_account_id=value, data_source_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.data.source.permission.update_multiple aws_account_id=value, data_source_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="update_data_source_permissions",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "DataSourceId": data_source_id,
            "GrantPermissions": grant_permissions,
            "RevokePermissions": revoke_permissions,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, environment_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets status information for an Cloud9 development environment.

    Args:
        environment_id(str): The ID of the environment to get status information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloud9.environment.status.describe(ctx, environment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloud9.environment.status.describe environment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloud9",
        operation="describe_environment_status",
        op_kwargs={"environmentId": environment_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, device_id: str, enabled: bool = None) -> Dict:
    r"""
       **Autogenerated function**

       Using a Boolean value (true or false), this operation
        enables or disables the device given a device ID.

       Args:
           device_id(str): The unique identifier of the device.
           enabled(bool, optional): If true, the device is enabled. If false, the device is
    disabled. Defaults to None.

       Returns:
           Dict

       Examples:
           Call from code:

           .. code-block:: python

               await hub.exec.aws_auto.iot1click_device.device.state.update(ctx, device_id=value)

           Call from CLI:

           .. code-block:: bash

               $ idem exec aws_auto.iot1click_device.device.state.update device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-devices",
        operation="update_device_state",
        op_kwargs={"DeviceId": device_id, "Enabled": enabled},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, problem_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the anomalies or errors associated with the problem.

    Args:
        problem_id(str): The ID of the problem.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.problem.observation.describe_all(
                ctx, problem_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.problem.observation.describe_all problem_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="describe_problem_observations",
        op_kwargs={"ProblemId": problem_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def put_multiple(
    hub, ctx, tracking_id: str, session_id: str, event_list: List, user_id: str = None
) -> None:
    r"""
    **Autogenerated function**

    Records user interaction event data. For more information see Recording Events.

    Args:
        tracking_id(str): The tracking ID for the event. The ID is generated by a call to the CreateEventTracker API.
        user_id(str, optional): The user associated with the event. Defaults to None.
        session_id(str): The session ID associated with the user's visit. Your application generates the sessionId when a user first visits your website or uses your application. Amazon Personalize uses the sessionId to associate events with the user before they log in. For more information, see Recording Events.
        event_list(List): A list of event data from the session.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize_event.event.put_multiple(
                ctx, tracking_id=value, session_id=value, event_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize_event.event.put_multiple tracking_id=value, session_id=value, event_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize-events",
        operation="put_events",
        op_kwargs={
            "trackingId": tracking_id,
            "userId": user_id,
            "sessionId": session_id,
            "eventList": event_list,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def put_multiple(
    hub,
    ctx,
    mail_type: str,
    website_url: str,
    use_case_description: str,
    contact_language: str = None,
    additional_contact_email_addresses: List = None,
    production_access_enabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update your Amazon SES account details.

    Args:
        mail_type(str): The type of email your account will send.
        website_url(str): The URL of your website. This information helps us better understand the type of content that you plan to send.
        contact_language(str, optional): The language you would prefer to be contacted with. Defaults to None.
        use_case_description(str): A description of the types of email that you plan to send.
        additional_contact_email_addresses(List, optional): Additional email addresses that you would like to be notified regarding Amazon SES matters. Defaults to None.
        production_access_enabled(bool, optional): Indicates whether or not your account should have production access in the current AWS Region. If the value is false, then your account is in the sandbox. When your account is in the sandbox, you can only send email to verified identities. Additionally, the maximum number of emails you can send in a 24-hour period (your sending quota) is 200, and the maximum number of emails you can send per second (your maximum sending rate) is 1. If the value is true, then your account has production access. When your account has production access, you can send email to any address. The sending quota and maximum sending rate for your account vary based on your specific use case. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.account.detail.put_multiple(
                ctx, mail_type=value, website_url=value, use_case_description=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.account.detail.put_multiple mail_type=value, website_url=value, use_case_description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="put_account_details",
        op_kwargs={
            "MailType": mail_type,
            "WebsiteURL": website_url,
            "ContactLanguage": contact_language,
            "UseCaseDescription": use_case_description,
            "AdditionalContactEmailAddresses": additional_contact_email_addresses,
            "ProductionAccessEnabled": production_access_enabled,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put(
    hub,
    ctx,
    deployment_id: str = None,
    lifecycle_event_hook_execution_id: str = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Sets the result of a Lambda validation function. The function validates lifecycle hooks during a deployment that uses the AWS Lambda or Amazon ECS compute platform. For AWS Lambda deployments, the available lifecycle hooks are BeforeAllowTraffic and AfterAllowTraffic. For Amazon ECS deployments, the available lifecycle hooks are BeforeInstall, AfterInstall, AfterAllowTestTraffic, BeforeAllowTraffic, and AfterAllowTraffic. Lambda validation functions return Succeeded or Failed. For more information, see AppSpec 'hooks' Section for an AWS Lambda Deployment  and AppSpec 'hooks' Section for an Amazon ECS Deployment.

    Args:
        deployment_id(str, optional):  The unique ID of a deployment. Pass this ID to a Lambda function that validates a deployment lifecycle event. . Defaults to None.
        lifecycle_event_hook_execution_id(str, optional):  The execution ID of a deployment's lifecycle hook. A deployment lifecycle hook is specified in the hooks section of the AppSpec file. . Defaults to None.
        status(str, optional): The result of a Lambda function that validates a deployment lifecycle event. Succeeded and Failed are the only valid values for status. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.lifecycle_event_hook_execution_status.put(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.lifecycle_event_hook_execution_status.put
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="put_lifecycle_event_hook_execution_status",
        op_kwargs={
            "deploymentId": deployment_id,
            "lifecycleEventHookExecutionId": lifecycle_event_hook_execution_id,
            "status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, ids: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about one or more custom data identifiers.

    Args:
        ids(List, optional): An array of strings that lists the unique identifiers for the custom data identifiers to retrieve information about. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.get_custom_data_identifier.batch(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.get_custom_data_identifier.batch
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="batch_get_custom_data_identifiers",
        op_kwargs={"ids": ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    template_active_version_request: Dict,
    template_name: str,
    template_type: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Changes the status of a specific version of a message template to active.

    Args:
        template_active_version_request(Dict): Specifies which version of a message template to use as the active version of the template.
        template_name(str): The name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.
        template_type(str): The type of channel that the message template is designed for. Valid values are: EMAIL, PUSH, SMS, and VOICE.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.template.active_version.update(
                ctx, template_active_version_request=value, template_name=value, template_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.template.active_version.update template_active_version_request=value, template_name=value, template_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="update_template_active_version",
        op_kwargs={
            "TemplateActiveVersionRequest": template_active_version_request,
            "TemplateName": template_name,
            "TemplateType": template_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def remove(hub, ctx, open_id_connect_provider_arn: str, client_id: str) -> None:
    r"""
    **Autogenerated function**

    Removes the specified client ID (also known as audience) from the list of client IDs registered for the specified IAM OpenID Connect (OIDC) provider resource object. This operation is idempotent; it does not fail or return an error if you try to remove a client ID that does not exist.

    Args:
        open_id_connect_provider_arn(str): The Amazon Resource Name (ARN) of the IAM OIDC provider resource to remove the client ID from. You can get a list of OIDC provider ARNs by using the ListOpenIDConnectProviders operation. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
        client_id(str): The client ID (also known as audience) to remove from the IAM OIDC provider resource. For more information about client IDs, see CreateOpenIDConnectProvider.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.client_id_.from_open_id_connect_provider.remove(
                ctx, open_id_connect_provider_arn=value, client_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.client_id_.from_open_id_connect_provider.remove open_id_connect_provider_arn=value, client_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="remove_client_id_from_open_id_connect_provider",
        op_kwargs={
            "OpenIDConnectProviderArn": open_id_connect_provider_arn,
            "ClientID": client_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def deregister(hub, ctx, directory_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deregisters the specified directory. This operation is asynchronous and returns before the WorkSpace directory is deregistered. If any WorkSpaces are registered to this directory, you must remove them before you can deregister the directory.  Simple AD and AD Connector are made available to you free of charge to use with WorkSpaces. If there are no WorkSpaces being used with your Simple AD or AD Connector directory for 30 consecutive days, this directory will be automatically deregistered for use with Amazon WorkSpaces, and you will be charged for this directory as per the AWS Directory Services pricing terms. To delete empty directories, see  Delete the Directory for Your WorkSpaces. If you delete your Simple AD or AD Connector directory, you can always create a new one when you want to start using WorkSpaces again.

    Args:
        directory_id(str): The identifier of the directory. If any WorkSpaces are registered to this directory, you must remove them before you deregister the directory, or you will receive an OperationNotSupportedException error.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.directory.deregister(
                ctx, directory_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.directory.deregister directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="deregister_workspace_directory",
        op_kwargs={"DirectoryId": directory_id},
    )


async def describe_all(
    hub, ctx, directory_ids: List = None, limit: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the available directories that are registered with Amazon WorkSpaces.

    Args:
        directory_ids(List, optional): The identifiers of the directories. If the value is null, all directories are retrieved. Defaults to None.
        limit(int, optional): The maximum number of directories to return. Defaults to None.
        next_token(str, optional): If you received a NextToken from a previous call that was paginated, provide this token to receive the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.directory.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.directory.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="describe_workspace_directories",
        op_kwargs={
            "DirectoryIds": directory_ids,
            "Limit": limit,
            "NextToken": next_token,
        },
    )


async def register(
    hub,
    ctx,
    directory_id: str,
    enable_work_docs: bool,
    subnet_ids: List = None,
    enable_self_service: bool = None,
    tenancy: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers the specified directory. This operation is asynchronous and returns before the WorkSpace directory is registered. If this is the first time you are registering a directory, you will need to create the workspaces_DefaultRole role before you can register a directory. For more information, see  Creating the workspaces_DefaultRole Role.

    Args:
        directory_id(str): The identifier of the directory. You cannot register a directory if it does not have a status of Active. If the directory does not have a status of Active, you will receive an InvalidResourceStateException error. If you have already registered the maximum number of directories that you can register with Amazon WorkSpaces, you will receive a ResourceLimitExceededException error. Deregister directories that you are not using for WorkSpaces, and try again.
        subnet_ids(List, optional): The identifiers of the subnets for your virtual private cloud (VPC). Make sure that the subnets are in supported Availability Zones. The subnets must also be in separate Availability Zones. If these conditions are not met, you will receive an OperationNotSupportedException error. Defaults to None.
        enable_work_docs(bool): Indicates whether Amazon WorkDocs is enabled or disabled. If you have enabled this parameter and WorkDocs is not available in the Region, you will receive an OperationNotSupportedException error. Set EnableWorkDocs to disabled, and try again.
        enable_self_service(bool, optional): Indicates whether self-service capabilities are enabled or disabled. Defaults to None.
        tenancy(str, optional): Indicates whether your WorkSpace directory is dedicated or shared. To use Bring Your Own License (BYOL) images, this value must be set to DEDICATED and your AWS account must be enabled for BYOL. If your account has not been enabled for BYOL, you will receive an InvalidParameterValuesException error. For more information about BYOL images, see Bring Your Own Windows Desktop Images. Defaults to None.
        tags(List, optional): The tags associated with the directory. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.directory.register(
                ctx, directory_id=value, enable_work_docs=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.directory.register directory_id=value, enable_work_docs=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="register_workspace_directory",
        op_kwargs={
            "DirectoryId": directory_id,
            "SubnetIds": subnet_ids,
            "EnableWorkDocs": enable_work_docs,
            "EnableSelfService": enable_self_service,
            "Tenancy": tenancy,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def preview(
    hub, ctx, preview_agents_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Previews the agents installed on the EC2 instances that are part of the specified assessment target.

    Args:
        preview_agents_arn(str): The ARN of the assessment target whose agents you want to preview.
        next_token(str, optional): You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the PreviewAgents action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data. Defaults to None.
        max_results(int, optional): You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.agent.preview(ctx, preview_agents_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.agent.preview preview_agents_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="preview_agents",
        op_kwargs={
            "previewAgentsArn": preview_agents_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def search(
    hub,
    ctx,
    system_instance_id: str,
    flow_execution_id: str = None,
    start_time: str = None,
    end_time: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches for AWS IoT Things Graph workflow execution instances.

    Args:
        system_instance_id(str): The ID of the system instance that contains the flow.
        flow_execution_id(str, optional): The ID of a flow execution. Defaults to None.
        start_time(str, optional): The date and time of the earliest flow execution to return. Defaults to None.
        end_time(str, optional): The date and time of the latest flow execution to return. Defaults to None.
        next_token(str, optional): The string that specifies the next page of results. Use this when you're paginating results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.flow.execution.init.search(
                ctx, system_instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.flow.execution.init.search system_instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="search_flow_executions",
        op_kwargs={
            "systemInstanceId": system_instance_id,
            "flowExecutionId": flow_execution_id,
            "startTime": start_time,
            "endTime": end_time,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put_multiple(
    hub,
    ctx,
    email_identity: str,
    mail_from_domain: str = None,
    behavior_on_mx_failure: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Used to enable or disable the custom Mail-From domain configuration for an email identity.

    Args:
        email_identity(str): The verified email identity that you want to set up the custom MAIL FROM domain for.
        mail_from_domain(str, optional):  The custom MAIL FROM domain that you want the verified identity to use. The MAIL FROM domain must meet the following criteria:   It has to be a subdomain of the verified identity.   It can't be used to receive email.   It can't be used in a "From" address if the MAIL FROM domain is a destination for feedback forwarding emails.  . Defaults to None.
        behavior_on_mx_failure(str, optional): The action that you want to take if the required MX record isn't found when you send an email. When you set this value to UseDefaultValue, the mail is sent using amazonses.com as the MAIL FROM domain. When you set this value to RejectMessage, the Amazon SES API v2 returns a MailFromDomainNotVerified error, and doesn't attempt to deliver the email. These behaviors are taken when the custom MAIL FROM domain configuration is in the Pending, Failed, and TemporaryFailure states. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.identity.mail_from_attribute.put_multiple(
                ctx, email_identity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.identity.mail_from_attribute.put_multiple email_identity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="put_email_identity_mail_from_attributes",
        op_kwargs={
            "EmailIdentity": email_identity,
            "MailFromDomain": mail_from_domain,
            "BehaviorOnMxFailure": behavior_on_mx_failure,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def evaluate(hub, ctx, pipeline_id: str, object_id: str, expression: str) -> Dict:
    r"""
    **Autogenerated function**

    Task runners call EvaluateExpression to evaluate a string in the context of the specified object. For example, a task runner can evaluate SQL queries stored in Amazon S3.

    Args:
        pipeline_id(str): The ID of the pipeline.
        object_id(str): The ID of the object.
        expression(str): The expression to evaluate.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datapipeline.expression.evaluate(
                ctx, pipeline_id=value, object_id=value, expression=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datapipeline.expression.evaluate pipeline_id=value, object_id=value, expression=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datapipeline",
        operation="evaluate_expression",
        op_kwargs={
            "pipelineId": pipeline_id,
            "objectId": object_id,
            "expression": expression,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    bucket: str,
    acl: str = None,
    create_bucket_configuration: Dict = None,
    grant_full_control: str = None,
    grant_read: str = None,
    grant_read_acp: str = None,
    grant_write: str = None,
    grant_write_acp: str = None,
    object_lock_enabled_for_bucket: bool = None,
    outpost_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This action creates an Amazon S3 on Outposts bucket. To create an S3 bucket, see Create Bucket in the Amazon S3 API Reference.   Creates a new Outposts bucket. By creating the bucket, you become the bucket owner. To create an Outposts bucket, you must have S3 on Outposts. For more information, see Using Amazon S3 on Outposts in Amazon S3 User Guide. Not every string is an acceptable bucket name. For information on bucket naming restrictions, see Working with Amazon S3 Buckets. S3 on Outposts buckets support:   Tags   LifecycleConfigurations for deleting expired objects   For a complete list of restrictions and Amazon S3 feature limitations on S3 on Outposts, see  Amazon S3 on Outposts Restrictions and Limitations. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and x-amz-outpost-id in your API request, see the Examples section. The following actions are related to CreateBucket for Amazon S3 on Outposts:    PutObject     GetBucket     DeleteBucket     CreateAccessPoint     PutAccessPointPolicy

    Args:
        acl(str, optional): The canned ACL to apply to the bucket.  This is not supported by Amazon S3 on Outposts buckets. . Defaults to None.
        bucket(str): The name of the bucket.
        create_bucket_configuration(Dict, optional): The configuration information for the bucket.  This is not supported by Amazon S3 on Outposts buckets. . Defaults to None.
        grant_full_control(str, optional): Allows grantee the read, write, read ACP, and write ACP permissions on the bucket.  This is not supported by Amazon S3 on Outposts buckets. . Defaults to None.
        grant_read(str, optional): Allows grantee to list the objects in the bucket.  This is not supported by Amazon S3 on Outposts buckets. . Defaults to None.
        grant_read_acp(str, optional): Allows grantee to read the bucket ACL.  This is not supported by Amazon S3 on Outposts buckets. . Defaults to None.
        grant_write(str, optional): Allows grantee to create, overwrite, and delete any object in the bucket.  This is not supported by Amazon S3 on Outposts buckets. . Defaults to None.
        grant_write_acp(str, optional): Allows grantee to write the ACL for the applicable bucket.  This is not supported by Amazon S3 on Outposts buckets. . Defaults to None.
        object_lock_enabled_for_bucket(bool, optional): Specifies whether you want S3 Object Lock to be enabled for the new bucket.  This is not supported by Amazon S3 on Outposts buckets. . Defaults to None.
        outpost_id(str, optional): The ID of the Outposts where the bucket is being created.  This is required by Amazon S3 on Outposts buckets. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.bucket.init.create(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.bucket.init.create bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="create_bucket",
        op_kwargs={
            "ACL": acl,
            "Bucket": bucket,
            "CreateBucketConfiguration": create_bucket_configuration,
            "GrantFullControl": grant_full_control,
            "GrantRead": grant_read,
            "GrantReadACP": grant_read_acp,
            "GrantWrite": grant_write,
            "GrantWriteACP": grant_write_acp,
            "ObjectLockEnabledForBucket": object_lock_enabled_for_bucket,
            "OutpostId": outpost_id,
        },
    )


async def delete(hub, ctx, account_id: str, bucket: str) -> None:
    r"""
    **Autogenerated function**

     This action deletes an Amazon S3 on Outposts bucket. To delete an S3 bucket, see DeleteBucket in the Amazon S3 API Reference.   Deletes the Amazon S3 on Outposts bucket. All objects (including all object versions and delete markers) in the bucket must be deleted before the bucket itself can be deleted. For more information, see Using Amazon S3 on Outposts in Amazon S3 User Guide. All Amazon S3 on Outposts REST API requests for this action require an additional parameter of x-amz-outpost-id to be passed with the request and an S3 on Outposts endpoint hostname prefix instead of s3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and the x-amz-outpost-id derived using the access point ARN, see the Examples section.  Related Resources     CreateBucket     GetBucket     DeleteObject

    Args:
        account_id(str): The account ID that owns the Outposts bucket.
        bucket(str): Specifies the bucket being deleted. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the bucket accessed in the format arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/bucket/<my-bucket-name>. For example, to access the bucket reports through outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports. The value must be URL encoded. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.bucket.init.delete(
                ctx, account_id=value, bucket=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.bucket.init.delete account_id=value, bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="delete_bucket",
        op_kwargs={"AccountId": account_id, "Bucket": bucket},
    )


async def get(hub, ctx, account_id: str, bucket: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets an Amazon S3 on Outposts bucket. For more information, see  Using Amazon S3 on Outposts in the Amazon S3 User Guide. If you are using an identity other than the root user of the account that owns the Outposts bucket, the calling identity must have the s3-outposts:GetBucket permissions on the specified Outposts bucket and belong to the Outposts bucket owner's account in order to use this action. Only users from Outposts bucket owner account with the right permissions can perform actions on an Outposts bucket.   If you don't have s3-outposts:GetBucket permissions or you're not using an identity that belongs to the bucket owner's account, Amazon S3 returns a 403 Access Denied error. The following actions are related to GetBucket for Amazon S3 on Outposts: All Amazon S3 on Outposts REST API requests for this action require an additional parameter of x-amz-outpost-id to be passed with the request and an S3 on Outposts endpoint hostname prefix instead of s3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and the x-amz-outpost-id derived using the access point ARN, see the Examples section.    PutObject     CreateBucket     DeleteBucket

    Args:
        account_id(str): The account ID of the Outposts bucket.
        bucket(str): Specifies the bucket. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the bucket accessed in the format arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/bucket/<my-bucket-name>. For example, to access the bucket reports through outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports. The value must be URL encoded. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.bucket.init.get(ctx, account_id=value, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.bucket.init.get account_id=value, bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="get_bucket",
        op_kwargs={"AccountId": account_id, "Bucket": bucket},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"set_": "set"}


async def get_all(hub, ctx, attributes: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the settings for sending SMS messages from your account. These settings are set with the SetSMSAttributes action.

    Args:
        attributes(List, optional): A list of the individual attribute names, such as MonthlySpendLimit, for which you want values. For all attribute names, see SetSMSAttributes. If you don't use this parameter, Amazon SNS returns all SMS attributes. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.sms.attribute.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.sms.attribute.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="get_sms_attributes",
        op_kwargs={"attributes": attributes},
    )


async def set_(hub, ctx, attributes: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Use this request to set the default settings for sending SMS messages and receiving daily SMS usage reports. You can override some of these settings for a single message when you use the Publish action with the MessageAttributes.entry.N parameter. For more information, see Publishing to a mobile phone in the Amazon SNS Developer Guide.  To use this operation, you must grant the Amazon SNS service principal (sns.amazonaws.com) permission to perform the s3:ListBucket action.

    Args:
        attributes(Dict): The default settings for sending SMS messages from your account. You can set values for the following attribute names:  MonthlySpendLimit – The maximum amount in USD that you are willing to spend each month to send SMS messages. When Amazon SNS determines that sending an SMS message would incur a cost that exceeds this limit, it stops sending SMS messages within minutes.  Amazon SNS stops sending SMS messages within minutes of the limit being crossed. During that interval, if you continue to send SMS messages, you will incur costs that exceed your limit.  By default, the spend limit is set to the maximum allowed by Amazon SNS. If you want to raise the limit, submit an SNS Limit Increase case. For New limit value, enter your desired monthly spend limit. In the Use Case Description field, explain that you are requesting an SMS monthly spend limit increase.  DeliveryStatusIAMRole – The ARN of the IAM role that allows Amazon SNS to write logs about SMS deliveries in CloudWatch Logs. For each SMS message that you send, Amazon SNS writes a log that includes the message price, the success or failure status, the reason for failure (if the message failed), the message dwell time, and other information.  DeliveryStatusSuccessSamplingRate – The percentage of successful SMS deliveries for which Amazon SNS will write logs in CloudWatch Logs. The value can be an integer from 0 - 100. For example, to write logs only for failed deliveries, set this value to 0. To write logs for 10% of your successful deliveries, set it to 10.  DefaultSenderID – A string, such as your business brand, that is displayed as the sender on the receiving device. Support for sender IDs varies by country. The sender ID can be 1 - 11 alphanumeric characters, and it must contain at least one letter.  DefaultSMSType – The type of SMS message that you will send by default. You can assign the following values:    Promotional – (Default) Noncritical messages, such as marketing messages. Amazon SNS optimizes the message delivery to incur the lowest cost.    Transactional – Critical messages that support customer transactions, such as one-time passcodes for multi-factor authentication. Amazon SNS optimizes the message delivery to achieve the highest reliability.    UsageReportS3Bucket – The name of the Amazon S3 bucket to receive daily SMS usage reports from Amazon SNS. Each day, Amazon SNS will deliver a usage report as a CSV file to the bucket. The report includes the following information for each SMS message that was successfully delivered by your account:   Time that the message was published (in UTC)   Message ID   Destination phone number   Message type   Delivery status   Message price (in USD)   Part number (a message is split into multiple parts if it is too long for a single message)   Total number of parts   To receive the report, the bucket must have a policy that allows the Amazon SNS service principal to perform the s3:PutObject and s3:GetBucketLocation actions. For an example bucket policy and usage report, see Monitoring SMS Activity in the Amazon SNS Developer Guide.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.sms.attribute.set(ctx, attributes=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.sms.attribute.set attributes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="set_sms_attributes",
        op_kwargs={"attributes": attributes},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    notebook_instance_name: str,
    session_expiration_duration_in_seconds: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a URL that you can use to connect to the Jupyter server from a notebook instance. In the Amazon SageMaker console, when you choose Open next to a notebook instance, Amazon SageMaker opens a new tab showing the Jupyter server home page from the notebook instance. The console uses this API to get the URL and show the page.  The IAM role or user used to call this API defines the permissions to access the notebook instance. Once the presigned URL is created, no additional permission is required to access this URL. IAM authorization policies for this API are also enforced for every HTTP request and WebSocket frame that attempts to connect to the notebook instance. You can restrict access to this API and to the URL that it returns to a list of IP addresses that you specify. Use the NotIpAddress condition operator and the aws:SourceIP condition context key to specify the list of IP addresses that you want to have access to the notebook instance. For more information, see Limit Access to a Notebook Instance by IP Address.  The URL that you get from a call to CreatePresignedNotebookInstanceUrl is valid only for 5 minutes. If you try to use the URL after the 5-minute limit expires, you are directed to the Amazon Web Services console sign-in page.

    Args:
        notebook_instance_name(str): The name of the notebook instance.
        session_expiration_duration_in_seconds(int, optional): The duration of the session, in seconds. The default is 12 hours. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.presigned.notebook_instance_url.create(
                ctx, notebook_instance_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.presigned.notebook_instance_url.create notebook_instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_presigned_notebook_instance_url",
        op_kwargs={
            "NotebookInstanceName": notebook_instance_name,
            "SessionExpirationDurationInSeconds": session_expiration_duration_in_seconds,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds tags to the specified AWS Elemental MediaStore container. Tags are key:value pairs that you can associate with AWS resources. For example, the tag key might be "customer" and the tag value might be "companyA." You can specify one or more tags to add to each container. You can add up to 50 tags to each container. For more information about tagging, including naming and usage conventions, see Tagging Resources in MediaStore.

    Args:
        resource(str): The Amazon Resource Name (ARN) for the container. .
        tags(List): An array of key:value pairs that you want to add to the container. You need to specify only the tags that you want to add or update. For example, suppose a container already has two tags (customer:CompanyA and priority:High). You want to change the priority tag and also add a third tag (type:Contract). For TagResource, you specify the following tags: priority:Medium, type:Contract. The result is that your container has three tags: customer:CompanyA, priority:Medium, and type:Contract.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore.resource.tag(ctx, resource=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore.resource.tag resource=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore",
        operation="tag_resource",
        op_kwargs={"Resource": resource, "Tags": tags},
    )


async def untag(hub, ctx, resource: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes tags from the specified container. You can specify one or more tags to remove.

    Args:
        resource(str): The Amazon Resource Name (ARN) for the container.
        tag_keys(List): A comma-separated list of keys for tags that you want to remove from the container. For example, if your container has two tags (customer:CompanyA and priority:High) and you want to remove one of the tags (priority:High), you specify the key for the tag that you want to remove (priority).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore.resource.untag(ctx, resource=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore.resource.untag resource=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore",
        operation="untag_resource",
        op_kwargs={"Resource": resource, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "engine_type"


async def describe_all(
    hub, ctx, engine_type: str = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describe available engine types and versions.

    Args:
        engine_type(str, optional): Filter response by engine type. Defaults to None.
        max_results(int, optional): The maximum number of brokers that Amazon MQ can return per page (20 by default). This value must be an integer from 5 to 100. Defaults to None.
        next_token(str, optional): The token that specifies the next page of results Amazon MQ should return. To request the first page, leave nextToken empty. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.broker.engine_type_.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.broker.engine_type.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="describe_broker_engine_types",
        op_kwargs={
            "EngineType": engine_type,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, registry_name: str, description: str = None, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a registry.

    Args:
        description(str, optional): A description of the registry to be created. Defaults to None.
        registry_name(str): The name of the registry.
        tags(Dict, optional): Tags to associate with the registry. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.registry.create(ctx, registry_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.registry.create registry_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="create_registry",
        op_kwargs={
            "Description": description,
            "RegistryName": registry_name,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, registry_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a Registry.

    Args:
        registry_name(str): The name of the registry.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.registry.delete(ctx, registry_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.registry.delete registry_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="delete_registry",
        op_kwargs={"RegistryName": registry_name},
    )


async def describe(hub, ctx, registry_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the registry.

    Args:
        registry_name(str): The name of the registry.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.registry.describe(ctx, registry_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.registry.describe registry_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="describe_registry",
        op_kwargs={"RegistryName": registry_name},
    )


async def list_all(
    hub,
    ctx,
    limit: int = None,
    next_token: str = None,
    registry_name_prefix: str = None,
    scope: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List the registries.

    Args:
        limit(int, optional): . Defaults to None.
        next_token(str, optional): The token that specifies the next page of results to return. To request the first page, leave NextToken empty. The token will expire in 24 hours, and cannot be shared with other accounts. Defaults to None.
        registry_name_prefix(str, optional): Specifying this limits the results to only those registry names that start with the specified prefix. Defaults to None.
        scope(str, optional): Can be set to Local or AWS to limit responses to your custom registries, or the ones provided by AWS. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.registry.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.registry.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="list_registries",
        op_kwargs={
            "Limit": limit,
            "NextToken": next_token,
            "RegistryNamePrefix": registry_name_prefix,
            "Scope": scope,
        },
    )


async def update(hub, ctx, registry_name: str, description: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates a registry.

    Args:
        description(str, optional): The description of the registry to update. Defaults to None.
        registry_name(str): The name of the registry.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.schemas.registry.update(ctx, registry_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.schemas.registry.update registry_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="schemas",
        operation="update_registry",
        op_kwargs={"Description": description, "RegistryName": registry_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, pool_name: str, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Create a new pool of dedicated IP addresses. A pool can include one or more dedicated IP addresses that are associated with your AWS account. You can associate a pool with a configuration set. When you send an email that uses that configuration set, the message is sent from one of the addresses in the associated pool.

    Args:
        pool_name(str): The name of the dedicated IP pool.
        tags(List, optional): An object that defines the tags (keys and values) that you want to associate with the pool. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.dedicated_ip.pool.create(ctx, pool_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.dedicated_ip.pool.create pool_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="create_dedicated_ip_pool",
        op_kwargs={"PoolName": pool_name, "Tags": tags},
    )


async def delete(hub, ctx, pool_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete a dedicated IP pool.

    Args:
        pool_name(str): The name of the dedicated IP pool that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.dedicated_ip.pool.delete(ctx, pool_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.dedicated_ip.pool.delete pool_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="delete_dedicated_ip_pool",
        op_kwargs={"PoolName": pool_name},
    )


async def list_all(hub, ctx, next_token: str = None, page_size: int = None) -> Dict:
    r"""
    **Autogenerated function**

    List all of the dedicated IP pools that exist in your AWS account in the current Region.

    Args:
        next_token(str, optional): A token returned from a previous call to ListDedicatedIpPools to indicate the position in the list of dedicated IP pools. Defaults to None.
        page_size(int, optional): The number of results to show in a single call to ListDedicatedIpPools. If the number of results is larger than the number you specified in this parameter, then the response includes a NextToken element, which you can use to obtain additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.dedicated_ip.pool.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.dedicated_ip.pool.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="list_dedicated_ip_pools",
        op_kwargs={"NextToken": next_token, "PageSize": page_size},
    )
